# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: index_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import utils_pb2 as utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13index_service.proto\x12\x0bsumma.proto\x1a\x0butils.proto\"3\n\nPrimaryKey\x12\r\n\x03str\x18\x01 \x01(\tH\x00\x12\r\n\x03i64\x18\x02 \x01(\x03H\x00\x42\x07\n\x05value\"\x19\n\x17\x41ttachFileEngineRequest\"\x1b\n\x19\x41ttachRemoteEngineRequest\"&\n\x17\x41ttachIpfsEngineRequest\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\"\x9b\x02\n\x12\x41ttachIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12J\n\x1a\x61ttach_file_engine_request\x18\x02 \x01(\x0b\x32$.summa.proto.AttachFileEngineRequestH\x00\x12N\n\x1c\x61ttach_remote_engine_request\x18\x03 \x01(\x0b\x32&.summa.proto.AttachRemoteEngineRequestH\x00\x12J\n\x1a\x61ttach_ipfs_engine_request\x18\x04 \x01(\x0b\x32$.summa.proto.AttachIpfsEngineRequestH\x00\x42\t\n\x07request\"C\n\x13\x41ttachIndexResponse\x12,\n\x05index\x18\x01 \x01(\x0b\x32\x1d.summa.proto.IndexDescription\"W\n\x12\x43ommitIndexRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12,\n\x0b\x63ommit_mode\x18\x02 \x01(\x0e\x32\x17.summa.proto.CommitMode\"A\n\x13\x43ommitIndexResponse\x12\x19\n\x0c\x65lapsed_secs\x18\x02 \x01(\x01H\x00\x88\x01\x01\x42\x0f\n\r_elapsed_secs\"?\n\x0bSortByField\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12!\n\x05order\x18\x02 \x01(\x0e\x32\x12.summa.proto.Order\"\xf9\x01\n\x0fIndexAttributes\x12\x12\n\ncreated_at\x18\x01 \x01(\x04\x12\x18\n\x0bprimary_key\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\x0e\x64\x65\x66\x61ult_fields\x18\x03 \x03(\t\x12\x14\n\x0cmulti_fields\x18\x04 \x03(\t\x12\x1f\n\x12\x64\x65\x66\x61ult_index_name\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x06 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x10\x64\x65\x66\x61ult_snippets\x18\x07 \x03(\tB\x0e\n\x0c_primary_keyB\x15\n\x13_default_index_nameB\x0e\n\x0c_description\"\xca\x02\n\x12\x43reateIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12;\n\x0cindex_engine\x18\x02 \x01(\x0e\x32%.summa.proto.CreateIndexEngineRequest\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12-\n\x0b\x63ompression\x18\x04 \x01(\x0e\x32\x18.summa.proto.Compression\x12\x16\n\tblocksize\x18\x05 \x01(\rH\x00\x88\x01\x01\x12\x34\n\rsort_by_field\x18\x06 \x01(\x0b\x32\x18.summa.proto.SortByFieldH\x01\x88\x01\x01\x12\x36\n\x10index_attributes\x18\x07 \x01(\x0b\x32\x1c.summa.proto.IndexAttributesB\x0c\n\n_blocksizeB\x10\n\x0e_sort_by_field\"C\n\x13\x43reateIndexResponse\x12,\n\x05index\x18\x01 \x01(\x0b\x32\x1d.summa.proto.IndexDescription\"Z\n\x15\x44\x65leteDocumentRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12,\n\x0bprimary_key\x18\x02 \x01(\x0b\x32\x17.summa.proto.PrimaryKey\"\x18\n\x16\x44\x65leteDocumentResponse\"(\n\x12\x44\x65leteIndexRequest\x12\x12\n\nindex_name\x18\x01 \x01(\t\"\x15\n\x13\x44\x65leteIndexResponse\"\x1a\n\x18GetIndicesAliasesRequest\"\xa7\x01\n\x19GetIndicesAliasesResponse\x12S\n\x0findices_aliases\x18\x01 \x03(\x0b\x32:.summa.proto.GetIndicesAliasesResponse.IndicesAliasesEntry\x1a\x35\n\x13IndicesAliasesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"&\n\x0fGetIndexRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\"@\n\x10GetIndexResponse\x12,\n\x05index\x18\x01 \x01(\x0b\x32\x1d.summa.proto.IndexDescription\"\x13\n\x11GetIndicesRequest\"D\n\x12GetIndicesResponse\x12.\n\x07indices\x18\x01 \x03(\x0b\x32\x1d.summa.proto.IndexDescription\"D\n\x1aIndexDocumentStreamRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12\x11\n\tdocuments\x18\x02 \x03(\x0c\"^\n\x1bIndexDocumentStreamResponse\x12\x14\n\x0csuccess_docs\x18\x01 \x01(\x04\x12\x13\n\x0b\x66\x61iled_docs\x18\x02 \x01(\x04\x12\x14\n\x0c\x65lapsed_secs\x18\x03 \x01(\x01\"=\n\x14IndexDocumentRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12\x10\n\x08\x64ocument\x18\x02 \x01(\x0c\"\x17\n\x15IndexDocumentResponse\"@\n\x14MergeSegmentsRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12\x13\n\x0bsegment_ids\x18\x02 \x03(\t\"\x17\n\x15MergeSegmentsResponse\"?\n\x14SetIndexAliasRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12\x12\n\nindex_name\x18\x02 \x01(\t\"G\n\x15SetIndexAliasResponse\x12\x1b\n\x0eold_index_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x11\n\x0f_old_index_name\")\n\x12VacuumIndexRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\"\x15\n\x13VacuumIndexResponse\" \n\x10\x46ileEngineConfig\x12\x0c\n\x04path\x18\x01 \x01(\t\"$\n\x12MemoryEngineConfig\x12\x0e\n\x06schema\x18\x01 \x01(\t\"P\n\x12\x43hunkedCacheConfig\x12\x12\n\nchunk_size\x18\x01 \x01(\x04\x12\x17\n\ncache_size\x18\x02 \x01(\x04H\x00\x88\x01\x01\x42\r\n\x0b_cache_size\"\x81\x02\n\x12RemoteEngineConfig\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x14\n\x0curl_template\x18\x02 \x01(\t\x12N\n\x10headers_template\x18\x03 \x03(\x0b\x32\x34.summa.proto.RemoteEngineConfig.HeadersTemplateEntry\x12=\n\x14\x63hunked_cache_config\x18\x04 \x01(\x0b\x32\x1f.summa.proto.ChunkedCacheConfig\x1a\x36\n\x14HeadersTemplateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1f\n\x10IpfsEngineConfig\x12\x0b\n\x03\x63id\x18\x01 \x01(\t\"\xe1\x01\n\x11IndexEngineConfig\x12-\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1d.summa.proto.FileEngineConfigH\x00\x12\x31\n\x06memory\x18\x02 \x01(\x0b\x32\x1f.summa.proto.MemoryEngineConfigH\x00\x12\x31\n\x06remote\x18\x03 \x01(\x0b\x32\x1f.summa.proto.RemoteEngineConfigH\x00\x12-\n\x04ipfs\x18\x04 \x01(\x0b\x32\x1d.summa.proto.IpfsEngineConfigH\x00\x42\x08\n\x06\x63onfig\"\xb4\x01\n\x10IndexDescription\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x15\n\rindex_aliases\x18\x02 \x03(\t\x12\x34\n\x0cindex_engine\x18\x03 \x01(\x0b\x32\x1e.summa.proto.IndexEngineConfig\x12\x10\n\x08num_docs\x18\x04 \x01(\x04\x12-\n\x0b\x63ompression\x18\x05 \x01(\x0e\x32\x18.summa.proto.Compression\"*\n\x16IndexDocumentOperation\x12\x10\n\x08\x64ocument\x18\x01 \x01(\x0c\"\\\n\x0eIndexOperation\x12=\n\x0eindex_document\x18\x02 \x01(\x0b\x32#.summa.proto.IndexDocumentOperationH\x00\x42\x0b\n\toperation*0\n\x18\x43reateIndexEngineRequest\x12\x08\n\x04\x46ile\x10\x00\x12\n\n\x06Memory\x10\x01*B\n\x0b\x43ompression\x12\x08\n\x04None\x10\x00\x12\n\n\x06\x42rotli\x10\x01\x12\x07\n\x03Lz4\x10\x02\x12\n\n\x06Snappy\x10\x03\x12\x08\n\x04Zstd\x10\x04*!\n\nCommitMode\x12\t\n\x05\x41sync\x10\x00\x12\x08\n\x04Sync\x10\x01\x32\x99\t\n\x08IndexApi\x12S\n\x0c\x61ttach_index\x12\x1f.summa.proto.AttachIndexRequest\x1a .summa.proto.AttachIndexResponse\"\x00\x12S\n\x0c\x63ommit_index\x12\x1f.summa.proto.CommitIndexRequest\x1a .summa.proto.CommitIndexResponse\"\x00\x12S\n\x0c\x63reate_index\x12\x1f.summa.proto.CreateIndexRequest\x1a .summa.proto.CreateIndexResponse\"\x00\x12\\\n\x0f\x64\x65lete_document\x12\".summa.proto.DeleteDocumentRequest\x1a#.summa.proto.DeleteDocumentResponse\"\x00\x12S\n\x0c\x64\x65lete_index\x12\x1f.summa.proto.DeleteIndexRequest\x1a .summa.proto.DeleteIndexResponse\"\x00\x12\x66\n\x13get_indices_aliases\x12%.summa.proto.GetIndicesAliasesRequest\x1a&.summa.proto.GetIndicesAliasesResponse\"\x00\x12J\n\tget_index\x12\x1c.summa.proto.GetIndexRequest\x1a\x1d.summa.proto.GetIndexResponse\"\x00\x12P\n\x0bget_indices\x12\x1e.summa.proto.GetIndicesRequest\x1a\x1f.summa.proto.GetIndicesResponse\"\x00\x12n\n\x15index_document_stream\x12\'.summa.proto.IndexDocumentStreamRequest\x1a(.summa.proto.IndexDocumentStreamResponse\"\x00(\x01\x12Y\n\x0eindex_document\x12!.summa.proto.IndexDocumentRequest\x1a\".summa.proto.IndexDocumentResponse\"\x00\x12Y\n\x0emerge_segments\x12!.summa.proto.MergeSegmentsRequest\x1a\".summa.proto.MergeSegmentsResponse\"\x00\x12Z\n\x0fset_index_alias\x12!.summa.proto.SetIndexAliasRequest\x1a\".summa.proto.SetIndexAliasResponse\"\x00\x12S\n\x0cvacuum_index\x12\x1f.summa.proto.VacuumIndexRequest\x1a .summa.proto.VacuumIndexResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'index_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETINDICESALIASESRESPONSE_INDICESALIASESENTRY._options = None
  _GETINDICESALIASESRESPONSE_INDICESALIASESENTRY._serialized_options = b'8\001'
  _REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY._options = None
  _REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY._serialized_options = b'8\001'
  _CREATEINDEXENGINEREQUEST._serialized_start=3551
  _CREATEINDEXENGINEREQUEST._serialized_end=3599
  _COMPRESSION._serialized_start=3601
  _COMPRESSION._serialized_end=3667
  _COMMITMODE._serialized_start=3669
  _COMMITMODE._serialized_end=3702
  _PRIMARYKEY._serialized_start=49
  _PRIMARYKEY._serialized_end=100
  _ATTACHFILEENGINEREQUEST._serialized_start=102
  _ATTACHFILEENGINEREQUEST._serialized_end=127
  _ATTACHREMOTEENGINEREQUEST._serialized_start=129
  _ATTACHREMOTEENGINEREQUEST._serialized_end=156
  _ATTACHIPFSENGINEREQUEST._serialized_start=158
  _ATTACHIPFSENGINEREQUEST._serialized_end=196
  _ATTACHINDEXREQUEST._serialized_start=199
  _ATTACHINDEXREQUEST._serialized_end=482
  _ATTACHINDEXRESPONSE._serialized_start=484
  _ATTACHINDEXRESPONSE._serialized_end=551
  _COMMITINDEXREQUEST._serialized_start=553
  _COMMITINDEXREQUEST._serialized_end=640
  _COMMITINDEXRESPONSE._serialized_start=642
  _COMMITINDEXRESPONSE._serialized_end=707
  _SORTBYFIELD._serialized_start=709
  _SORTBYFIELD._serialized_end=772
  _INDEXATTRIBUTES._serialized_start=775
  _INDEXATTRIBUTES._serialized_end=1024
  _CREATEINDEXREQUEST._serialized_start=1027
  _CREATEINDEXREQUEST._serialized_end=1357
  _CREATEINDEXRESPONSE._serialized_start=1359
  _CREATEINDEXRESPONSE._serialized_end=1426
  _DELETEDOCUMENTREQUEST._serialized_start=1428
  _DELETEDOCUMENTREQUEST._serialized_end=1518
  _DELETEDOCUMENTRESPONSE._serialized_start=1520
  _DELETEDOCUMENTRESPONSE._serialized_end=1544
  _DELETEINDEXREQUEST._serialized_start=1546
  _DELETEINDEXREQUEST._serialized_end=1586
  _DELETEINDEXRESPONSE._serialized_start=1588
  _DELETEINDEXRESPONSE._serialized_end=1609
  _GETINDICESALIASESREQUEST._serialized_start=1611
  _GETINDICESALIASESREQUEST._serialized_end=1637
  _GETINDICESALIASESRESPONSE._serialized_start=1640
  _GETINDICESALIASESRESPONSE._serialized_end=1807
  _GETINDICESALIASESRESPONSE_INDICESALIASESENTRY._serialized_start=1754
  _GETINDICESALIASESRESPONSE_INDICESALIASESENTRY._serialized_end=1807
  _GETINDEXREQUEST._serialized_start=1809
  _GETINDEXREQUEST._serialized_end=1847
  _GETINDEXRESPONSE._serialized_start=1849
  _GETINDEXRESPONSE._serialized_end=1913
  _GETINDICESREQUEST._serialized_start=1915
  _GETINDICESREQUEST._serialized_end=1934
  _GETINDICESRESPONSE._serialized_start=1936
  _GETINDICESRESPONSE._serialized_end=2004
  _INDEXDOCUMENTSTREAMREQUEST._serialized_start=2006
  _INDEXDOCUMENTSTREAMREQUEST._serialized_end=2074
  _INDEXDOCUMENTSTREAMRESPONSE._serialized_start=2076
  _INDEXDOCUMENTSTREAMRESPONSE._serialized_end=2170
  _INDEXDOCUMENTREQUEST._serialized_start=2172
  _INDEXDOCUMENTREQUEST._serialized_end=2233
  _INDEXDOCUMENTRESPONSE._serialized_start=2235
  _INDEXDOCUMENTRESPONSE._serialized_end=2258
  _MERGESEGMENTSREQUEST._serialized_start=2260
  _MERGESEGMENTSREQUEST._serialized_end=2324
  _MERGESEGMENTSRESPONSE._serialized_start=2326
  _MERGESEGMENTSRESPONSE._serialized_end=2349
  _SETINDEXALIASREQUEST._serialized_start=2351
  _SETINDEXALIASREQUEST._serialized_end=2414
  _SETINDEXALIASRESPONSE._serialized_start=2416
  _SETINDEXALIASRESPONSE._serialized_end=2487
  _VACUUMINDEXREQUEST._serialized_start=2489
  _VACUUMINDEXREQUEST._serialized_end=2530
  _VACUUMINDEXRESPONSE._serialized_start=2532
  _VACUUMINDEXRESPONSE._serialized_end=2553
  _FILEENGINECONFIG._serialized_start=2555
  _FILEENGINECONFIG._serialized_end=2587
  _MEMORYENGINECONFIG._serialized_start=2589
  _MEMORYENGINECONFIG._serialized_end=2625
  _CHUNKEDCACHECONFIG._serialized_start=2627
  _CHUNKEDCACHECONFIG._serialized_end=2707
  _REMOTEENGINECONFIG._serialized_start=2710
  _REMOTEENGINECONFIG._serialized_end=2967
  _REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY._serialized_start=2913
  _REMOTEENGINECONFIG_HEADERSTEMPLATEENTRY._serialized_end=2967
  _IPFSENGINECONFIG._serialized_start=2969
  _IPFSENGINECONFIG._serialized_end=3000
  _INDEXENGINECONFIG._serialized_start=3003
  _INDEXENGINECONFIG._serialized_end=3228
  _INDEXDESCRIPTION._serialized_start=3231
  _INDEXDESCRIPTION._serialized_end=3411
  _INDEXDOCUMENTOPERATION._serialized_start=3413
  _INDEXDOCUMENTOPERATION._serialized_end=3455
  _INDEXOPERATION._serialized_start=3457
  _INDEXOPERATION._serialized_end=3549
  _INDEXAPI._serialized_start=3705
  _INDEXAPI._serialized_end=4882
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import utils_pb2 as utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bquery.proto\x12\x0bsumma.proto\x1a\x0butils.proto\"s\n\x0eSearchResponse\x12\x12\n\nindex_name\x18\x01 \x01(\t\x12\x37\n\x11\x63ollector_outputs\x18\x02 \x03(\x0b\x32\x1c.summa.proto.CollectorOutput\x12\x14\n\x0c\x65lapsed_secs\x18\x03 \x01(\x01\"\x81\x04\n\x05Query\x12,\n\x07\x62oolean\x18\x01 \x01(\x0b\x32\x19.summa.proto.BooleanQueryH\x00\x12(\n\x05match\x18\x02 \x01(\x0b\x32\x17.summa.proto.MatchQueryH\x00\x12(\n\x05regex\x18\x03 \x01(\x0b\x32\x17.summa.proto.RegexQueryH\x00\x12&\n\x04term\x18\x04 \x01(\x0b\x32\x16.summa.proto.TermQueryH\x00\x12*\n\x06phrase\x18\x05 \x01(\x0b\x32\x18.summa.proto.PhraseQueryH\x00\x12(\n\x05range\x18\x06 \x01(\x0b\x32\x17.summa.proto.RangeQueryH\x00\x12$\n\x03\x61ll\x18\x07 \x01(\x0b\x32\x15.summa.proto.AllQueryH\x00\x12\x38\n\x0emore_like_this\x18\x08 \x01(\x0b\x32\x1e.summa.proto.MoreLikeThisQueryH\x00\x12(\n\x05\x62oost\x18\t \x01(\x0b\x32\x17.summa.proto.BoostQueryH\x00\x12;\n\x0f\x64isjunction_max\x18\n \x01(\x0b\x32 .summa.proto.DisjunctionMaxQueryH\x00\x12(\n\x05\x65mpty\x18\x0b \x01(\x0b\x32\x17.summa.proto.EmptyQueryH\x00\x42\x07\n\x05query\"\n\n\x08\x41llQuery\"\x0c\n\nEmptyQuery\">\n\nBoostQuery\x12!\n\x05query\x18\x01 \x01(\x0b\x32\x12.summa.proto.Query\x12\r\n\x05score\x18\x02 \x01(\t\"Q\n\x13\x44isjunctionMaxQuery\x12%\n\tdisjuncts\x18\x01 \x03(\x0b\x32\x12.summa.proto.Query\x12\x13\n\x0btie_breaker\x18\x02 \x01(\t\"\x91\x03\n\x11MoreLikeThisQuery\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12\x1e\n\x11min_doc_frequency\x18\x02 \x01(\x04H\x00\x88\x01\x01\x12\x1e\n\x11max_doc_frequency\x18\x03 \x01(\x04H\x01\x88\x01\x01\x12\x1f\n\x12min_term_frequency\x18\x04 \x01(\x04H\x02\x88\x01\x01\x12\x1c\n\x0fmax_query_terms\x18\x05 \x01(\x04H\x03\x88\x01\x01\x12\x1c\n\x0fmin_word_length\x18\x06 \x01(\x04H\x04\x88\x01\x01\x12\x1c\n\x0fmax_word_length\x18\x07 \x01(\x04H\x05\x88\x01\x01\x12\x12\n\x05\x62oost\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x12\n\nstop_words\x18\t \x03(\tB\x14\n\x12_min_doc_frequencyB\x14\n\x12_max_doc_frequencyB\x15\n\x13_min_term_frequencyB\x12\n\x10_max_query_termsB\x12\n\x10_min_word_lengthB\x12\n\x10_max_word_lengthB\x08\n\x06_boost\"9\n\x0bPhraseQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04slop\x18\x03 \x01(\r\">\n\nRangeQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.summa.proto.Range\"\x1b\n\nMatchQuery\x12\r\n\x05value\x18\x01 \x01(\t\"W\n\x0f\x42ooleanSubquery\x12!\n\x05occur\x18\x01 \x01(\x0e\x32\x12.summa.proto.Occur\x12!\n\x05query\x18\x02 \x01(\x0b\x32\x12.summa.proto.Query\"@\n\x0c\x42ooleanQuery\x12\x30\n\nsubqueries\x18\x01 \x03(\x0b\x32\x1c.summa.proto.BooleanSubquery\"*\n\nRegexQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\")\n\tTermQuery\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\x80\x01\n\x0b\x41ggregation\x12\x30\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x1e.summa.proto.BucketAggregationH\x00\x12\x30\n\x06metric\x18\x02 \x01(\x0b\x32\x1e.summa.proto.MetricAggregationH\x00\x42\r\n\x0b\x61ggregation\"\xd7\x02\n\x11\x42ucketAggregation\x12.\n\x05range\x18\x01 \x01(\x0b\x32\x1d.summa.proto.RangeAggregationH\x00\x12\x36\n\thistogram\x18\x02 \x01(\x0b\x32!.summa.proto.HistogramAggregationH\x00\x12.\n\x05terms\x18\x03 \x01(\x0b\x32\x1d.summa.proto.TermsAggregationH\x00\x12K\n\x0fsub_aggregation\x18\x04 \x03(\x0b\x32\x32.summa.proto.BucketAggregation.SubAggregationEntry\x1aO\n\x13SubAggregationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.summa.proto.Aggregation:\x02\x38\x01\x42\x0c\n\nbucket_agg\"U\n\x10RangeAggregation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x32\n\x06ranges\x18\x02 \x03(\x0b\x32\".summa.proto.RangeAggregationRange\"e\n\x15RangeAggregationRange\x12\x11\n\x04\x66rom\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x0f\n\x02to\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x10\n\x03key\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_fromB\x05\n\x03_toB\x06\n\x04_key\"\x9d\x02\n\x14HistogramAggregation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x10\n\x08interval\x18\x02 \x01(\x01\x12\x13\n\x06offset\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x1a\n\rmin_doc_count\x18\x04 \x01(\x04H\x01\x88\x01\x01\x12\x36\n\x0bhard_bounds\x18\x05 \x01(\x0b\x32\x1c.summa.proto.HistogramBoundsH\x02\x88\x01\x01\x12:\n\x0f\x65xtended_bounds\x18\x06 \x01(\x0b\x32\x1c.summa.proto.HistogramBoundsH\x03\x88\x01\x01\x42\t\n\x07_offsetB\x10\n\x0e_min_doc_countB\x0e\n\x0c_hard_boundsB\x12\n\x10_extended_bounds\"+\n\x0fHistogramBounds\x12\x0b\n\x03min\x18\x01 \x01(\x01\x12\x0b\n\x03max\x18\x02 \x01(\x01\"\xbd\x02\n\x10TermsAggregation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x11\n\x04size\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x17\n\nsplit_size\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x19\n\x0csegment_size\x18\x04 \x01(\rH\x02\x88\x01\x01\x12&\n\x19show_term_doc_count_error\x18\x05 \x01(\x08H\x03\x88\x01\x01\x12\x1a\n\rmin_doc_count\x18\x06 \x01(\x04H\x04\x88\x01\x01\x12,\n\x05order\x18\x07 \x01(\x0b\x32\x18.summa.proto.CustomOrderH\x05\x88\x01\x01\x42\x07\n\x05_sizeB\r\n\x0b_split_sizeB\x0f\n\r_segment_sizeB\x1c\n\x1a_show_term_doc_count_errorB\x10\n\x0e_min_doc_countB\x08\n\x06_order\"\xa3\x01\n\x0b\x43ustomOrder\x12!\n\x03key\x18\x01 \x01(\x0b\x32\x12.summa.proto.EmptyH\x00\x12#\n\x05\x63ount\x18\x02 \x01(\x0b\x32\x12.summa.proto.EmptyH\x00\x12\x19\n\x0fsub_aggregation\x18\x03 \x01(\tH\x00\x12!\n\x05order\x18\x04 \x01(\x0e\x32\x12.summa.proto.OrderB\x0e\n\x0corder_target\"\x8d\x01\n\x11MetricAggregation\x12\x32\n\x07\x61verage\x18\x01 \x01(\x0b\x32\x1f.summa.proto.AverageAggregationH\x00\x12.\n\x05stats\x18\x02 \x01(\x0b\x32\x1d.summa.proto.StatsAggregationH\x00\x42\x14\n\x12metric_aggregation\"#\n\x12\x41verageAggregation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"!\n\x10StatsAggregation\x12\r\n\x05\x66ield\x18\x01 \x01(\t\"\xdd\x01\n\x0b\x42ucketEntry\x12\x1d\n\x03key\x18\x01 \x01(\x0b\x32\x10.summa.proto.Key\x12\x11\n\tdoc_count\x18\x02 \x01(\x04\x12\x45\n\x0fsub_aggregation\x18\x03 \x03(\x0b\x32,.summa.proto.BucketEntry.SubAggregationEntry\x1aU\n\x13SubAggregationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.summa.proto.AggregationResult:\x02\x38\x01\"*\n\x03Key\x12\r\n\x03str\x18\x01 \x01(\tH\x00\x12\r\n\x03\x66\x36\x34\x18\x02 \x01(\x01H\x00\x42\x05\n\x03key\"U\n\x05Range\x12\x0c\n\x04left\x18\x01 \x01(\t\x12\r\n\x05right\x18\x02 \x01(\t\x12\x16\n\x0eincluding_left\x18\x03 \x01(\x08\x12\x17\n\x0fincluding_right\x18\x04 \x01(\x08\"\x9b\x02\n\x10RangeBucketEntry\x12\x1d\n\x03key\x18\x01 \x01(\x0b\x32\x10.summa.proto.Key\x12\x11\n\tdoc_count\x18\x02 \x01(\x04\x12J\n\x0fsub_aggregation\x18\x03 \x03(\x0b\x32\x31.summa.proto.RangeBucketEntry.SubAggregationEntry\x12\x11\n\x04\x66rom\x18\x04 \x01(\x01H\x00\x88\x01\x01\x12\x0f\n\x02to\x18\x05 \x01(\x01H\x01\x88\x01\x01\x1aU\n\x13SubAggregationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.summa.proto.AggregationResult:\x02\x38\x01\x42\x07\n\x05_fromB\x05\n\x03_to\":\n\x05Score\x12\x13\n\tf64_score\x18\x01 \x01(\x01H\x00\x12\x13\n\tu64_score\x18\x02 \x01(\x04H\x00\x42\x07\n\x05score\"%\n\tHighlight\x12\x0c\n\x04\x66rom\x18\x01 \x01(\r\x12\n\n\x02to\x18\x02 \x01(\r\"U\n\x07Snippet\x12\x10\n\x08\x66ragment\x18\x01 \x01(\x0c\x12*\n\nhighlights\x18\x02 \x03(\x0b\x32\x16.summa.proto.Highlight\x12\x0c\n\x04html\x18\x03 \x01(\t\"\xf0\x01\n\x0eScoredDocument\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12!\n\x05score\x18\x02 \x01(\x0b\x32\x12.summa.proto.Score\x12\x10\n\x08position\x18\x03 \x01(\r\x12;\n\x08snippets\x18\x04 \x03(\x0b\x32).summa.proto.ScoredDocument.SnippetsEntry\x12\x13\n\x0bindex_alias\x18\x05 \x01(\t\x1a\x45\n\rSnippetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.summa.proto.Snippet:\x02\x38\x01\";\n\x06Scorer\x12\x13\n\teval_expr\x18\x01 \x01(\tH\x00\x12\x12\n\x08order_by\x18\x02 \x01(\tH\x00\x42\x08\n\x06scorer\"\xa8\x02\n\tCollector\x12\x31\n\x08top_docs\x18\x01 \x01(\x0b\x32\x1d.summa.proto.TopDocsCollectorH\x00\x12\x45\n\x12reservoir_sampling\x18\x02 \x01(\x0b\x32\'.summa.proto.ReservoirSamplingCollectorH\x00\x12,\n\x05\x63ount\x18\x03 \x01(\x0b\x32\x1b.summa.proto.CountCollectorH\x00\x12,\n\x05\x66\x61\x63\x65t\x18\x04 \x01(\x0b\x32\x1b.summa.proto.FacetCollectorH\x00\x12\x38\n\x0b\x61ggregation\x18\x05 \x01(\x0b\x32!.summa.proto.AggregationCollectorH\x00\x42\x0b\n\tcollector\"\xd3\x02\n\x0f\x43ollectorOutput\x12\x37\n\x08top_docs\x18\x01 \x01(\x0b\x32#.summa.proto.TopDocsCollectorOutputH\x00\x12K\n\x12reservoir_sampling\x18\x02 \x01(\x0b\x32-.summa.proto.ReservoirSamplingCollectorOutputH\x00\x12\x32\n\x05\x63ount\x18\x03 \x01(\x0b\x32!.summa.proto.CountCollectorOutputH\x00\x12\x32\n\x05\x66\x61\x63\x65t\x18\x04 \x01(\x0b\x32!.summa.proto.FacetCollectorOutputH\x00\x12>\n\x0b\x61ggregation\x18\x05 \x01(\x0b\x32\'.summa.proto.AggregationCollectorOutputH\x00\x42\x12\n\x10\x63ollector_output\"\x10\n\x0e\x43ountCollector\"%\n\x14\x43ountCollectorOutput\x12\r\n\x05\x63ount\x18\x01 \x01(\r\"/\n\x0e\x46\x61\x63\x65tCollector\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x0e\n\x06\x66\x61\x63\x65ts\x18\x02 \x03(\t\"\x94\x01\n\x14\x46\x61\x63\x65tCollectorOutput\x12H\n\x0c\x66\x61\x63\x65t_counts\x18\x01 \x03(\x0b\x32\x32.summa.proto.FacetCollectorOutput.FacetCountsEntry\x1a\x32\n\x10\x46\x61\x63\x65tCountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\";\n\x1aReservoirSamplingCollector\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\"Z\n\x0eRandomDocument\x12\x10\n\x08\x64ocument\x18\x01 \x01(\t\x12!\n\x05score\x18\x02 \x01(\x0b\x32\x12.summa.proto.Score\x12\x13\n\x0bindex_alias\x18\x03 \x01(\t\"Y\n ReservoirSamplingCollectorOutput\x12\x35\n\x10random_documents\x18\x01 \x03(\x0b\x32\x1b.summa.proto.RandomDocument\"\xf7\x01\n\x10TopDocsCollector\x12\r\n\x05limit\x18\x01 \x01(\r\x12\x0e\n\x06offset\x18\x02 \x01(\r\x12(\n\x06scorer\x18\x03 \x01(\x0b\x32\x13.summa.proto.ScorerH\x00\x88\x01\x01\x12=\n\x08snippets\x18\x04 \x03(\x0b\x32+.summa.proto.TopDocsCollector.SnippetsEntry\x12\x0f\n\x07\x65xplain\x18\x05 \x01(\x08\x12\x0e\n\x06\x66ields\x18\x06 \x03(\t\x1a/\n\rSnippetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\x42\t\n\x07_scorer\"a\n\x16TopDocsCollectorOutput\x12\x35\n\x10scored_documents\x18\x01 \x03(\x0b\x32\x1b.summa.proto.ScoredDocument\x12\x10\n\x08has_next\x18\x02 \x01(\x08\"\xb0\x01\n\x14\x41ggregationCollector\x12I\n\x0c\x61ggregations\x18\x01 \x03(\x0b\x32\x33.summa.proto.AggregationCollector.AggregationsEntry\x1aM\n\x11\x41ggregationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.summa.proto.Aggregation:\x02\x38\x01\"\xd5\x01\n\x1a\x41ggregationCollectorOutput\x12\\\n\x13\x61ggregation_results\x18\x01 \x03(\x0b\x32?.summa.proto.AggregationCollectorOutput.AggregationResultsEntry\x1aY\n\x17\x41ggregationResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.summa.proto.AggregationResult:\x02\x38\x01\"\x83\x01\n\x11\x41ggregationResult\x12+\n\x06\x62ucket\x18\x01 \x01(\x0b\x32\x19.summa.proto.BucketResultH\x00\x12+\n\x06metric\x18\x02 \x01(\x0b\x32\x19.summa.proto.MetricResultH\x00\x42\x14\n\x12\x61ggregation_result\"\xa8\x01\n\x0c\x42ucketResult\x12)\n\x05range\x18\x01 \x01(\x0b\x32\x18.summa.proto.RangeResultH\x00\x12\x31\n\thistogram\x18\x02 \x01(\x0b\x32\x1c.summa.proto.HistogramResultH\x00\x12)\n\x05terms\x18\x03 \x01(\x0b\x32\x18.summa.proto.TermsResultH\x00\x42\x0f\n\rbucket_result\"=\n\x0bRangeResult\x12.\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x1d.summa.proto.RangeBucketEntry\"<\n\x0fHistogramResult\x12)\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x18.summa.proto.BucketEntry\"\x9f\x01\n\x0bTermsResult\x12)\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x18.summa.proto.BucketEntry\x12\x1b\n\x13sum_other_doc_count\x18\x02 \x01(\x04\x12(\n\x1b\x64oc_count_error_upper_bound\x18\x03 \x01(\x04H\x00\x88\x01\x01\x42\x1e\n\x1c_doc_count_error_upper_bound\"\x84\x01\n\x0cMetricResult\x12\x38\n\rsingle_metric\x18\x01 \x01(\x0b\x32\x1f.summa.proto.SingleMetricResultH\x00\x12)\n\x05stats\x18\x02 \x01(\x0b\x32\x18.summa.proto.StatsResultH\x00\x42\x0f\n\rmetric_result\"2\n\x12SingleMetricResult\x12\x12\n\x05value\x18\x01 \x01(\x01H\x00\x88\x01\x01\x42\x08\n\x06_value\"\xaf\x01\n\x0bStatsResult\x12\r\n\x05\x63ount\x18\x01 \x01(\x04\x12\x0b\n\x03sum\x18\x02 \x01(\x01\x12\x1f\n\x12standard_deviation\x18\x03 \x01(\x01H\x00\x88\x01\x01\x12\x10\n\x03min\x18\x04 \x01(\x01H\x01\x88\x01\x01\x12\x10\n\x03max\x18\x05 \x01(\x01H\x02\x88\x01\x01\x12\x10\n\x03\x61vg\x18\x06 \x01(\x01H\x03\x88\x01\x01\x42\x15\n\x13_standard_deviationB\x06\n\x04_minB\x06\n\x04_maxB\x06\n\x04_avg*+\n\x05Occur\x12\n\n\x06should\x10\x00\x12\x08\n\x04must\x10\x01\x12\x0c\n\x08must_not\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BUCKETAGGREGATION_SUBAGGREGATIONENTRY._options = None
  _BUCKETAGGREGATION_SUBAGGREGATIONENTRY._serialized_options = b'8\001'
  _BUCKETENTRY_SUBAGGREGATIONENTRY._options = None
  _BUCKETENTRY_SUBAGGREGATIONENTRY._serialized_options = b'8\001'
  _RANGEBUCKETENTRY_SUBAGGREGATIONENTRY._options = None
  _RANGEBUCKETENTRY_SUBAGGREGATIONENTRY._serialized_options = b'8\001'
  _SCOREDDOCUMENT_SNIPPETSENTRY._options = None
  _SCOREDDOCUMENT_SNIPPETSENTRY._serialized_options = b'8\001'
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._options = None
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._serialized_options = b'8\001'
  _TOPDOCSCOLLECTOR_SNIPPETSENTRY._options = None
  _TOPDOCSCOLLECTOR_SNIPPETSENTRY._serialized_options = b'8\001'
  _AGGREGATIONCOLLECTOR_AGGREGATIONSENTRY._options = None
  _AGGREGATIONCOLLECTOR_AGGREGATIONSENTRY._serialized_options = b'8\001'
  _AGGREGATIONCOLLECTOROUTPUT_AGGREGATIONRESULTSENTRY._options = None
  _AGGREGATIONCOLLECTOROUTPUT_AGGREGATIONRESULTSENTRY._serialized_options = b'8\001'
  _OCCUR._serialized_start=7321
  _OCCUR._serialized_end=7364
  _SEARCHRESPONSE._serialized_start=41
  _SEARCHRESPONSE._serialized_end=156
  _QUERY._serialized_start=159
  _QUERY._serialized_end=672
  _ALLQUERY._serialized_start=674
  _ALLQUERY._serialized_end=684
  _EMPTYQUERY._serialized_start=686
  _EMPTYQUERY._serialized_end=698
  _BOOSTQUERY._serialized_start=700
  _BOOSTQUERY._serialized_end=762
  _DISJUNCTIONMAXQUERY._serialized_start=764
  _DISJUNCTIONMAXQUERY._serialized_end=845
  _MORELIKETHISQUERY._serialized_start=848
  _MORELIKETHISQUERY._serialized_end=1249
  _PHRASEQUERY._serialized_start=1251
  _PHRASEQUERY._serialized_end=1308
  _RANGEQUERY._serialized_start=1310
  _RANGEQUERY._serialized_end=1372
  _MATCHQUERY._serialized_start=1374
  _MATCHQUERY._serialized_end=1401
  _BOOLEANSUBQUERY._serialized_start=1403
  _BOOLEANSUBQUERY._serialized_end=1490
  _BOOLEANQUERY._serialized_start=1492
  _BOOLEANQUERY._serialized_end=1556
  _REGEXQUERY._serialized_start=1558
  _REGEXQUERY._serialized_end=1600
  _TERMQUERY._serialized_start=1602
  _TERMQUERY._serialized_end=1643
  _AGGREGATION._serialized_start=1646
  _AGGREGATION._serialized_end=1774
  _BUCKETAGGREGATION._serialized_start=1777
  _BUCKETAGGREGATION._serialized_end=2120
  _BUCKETAGGREGATION_SUBAGGREGATIONENTRY._serialized_start=2027
  _BUCKETAGGREGATION_SUBAGGREGATIONENTRY._serialized_end=2106
  _RANGEAGGREGATION._serialized_start=2122
  _RANGEAGGREGATION._serialized_end=2207
  _RANGEAGGREGATIONRANGE._serialized_start=2209
  _RANGEAGGREGATIONRANGE._serialized_end=2310
  _HISTOGRAMAGGREGATION._serialized_start=2313
  _HISTOGRAMAGGREGATION._serialized_end=2598
  _HISTOGRAMBOUNDS._serialized_start=2600
  _HISTOGRAMBOUNDS._serialized_end=2643
  _TERMSAGGREGATION._serialized_start=2646
  _TERMSAGGREGATION._serialized_end=2963
  _CUSTOMORDER._serialized_start=2966
  _CUSTOMORDER._serialized_end=3129
  _METRICAGGREGATION._serialized_start=3132
  _METRICAGGREGATION._serialized_end=3273
  _AVERAGEAGGREGATION._serialized_start=3275
  _AVERAGEAGGREGATION._serialized_end=3310
  _STATSAGGREGATION._serialized_start=3312
  _STATSAGGREGATION._serialized_end=3345
  _BUCKETENTRY._serialized_start=3348
  _BUCKETENTRY._serialized_end=3569
  _BUCKETENTRY_SUBAGGREGATIONENTRY._serialized_start=3484
  _BUCKETENTRY_SUBAGGREGATIONENTRY._serialized_end=3569
  _KEY._serialized_start=3571
  _KEY._serialized_end=3613
  _RANGE._serialized_start=3615
  _RANGE._serialized_end=3700
  _RANGEBUCKETENTRY._serialized_start=3703
  _RANGEBUCKETENTRY._serialized_end=3986
  _RANGEBUCKETENTRY_SUBAGGREGATIONENTRY._serialized_start=3484
  _RANGEBUCKETENTRY_SUBAGGREGATIONENTRY._serialized_end=3569
  _SCORE._serialized_start=3988
  _SCORE._serialized_end=4046
  _HIGHLIGHT._serialized_start=4048
  _HIGHLIGHT._serialized_end=4085
  _SNIPPET._serialized_start=4087
  _SNIPPET._serialized_end=4172
  _SCOREDDOCUMENT._serialized_start=4175
  _SCOREDDOCUMENT._serialized_end=4415
  _SCOREDDOCUMENT_SNIPPETSENTRY._serialized_start=4346
  _SCOREDDOCUMENT_SNIPPETSENTRY._serialized_end=4415
  _SCORER._serialized_start=4417
  _SCORER._serialized_end=4476
  _COLLECTOR._serialized_start=4479
  _COLLECTOR._serialized_end=4775
  _COLLECTOROUTPUT._serialized_start=4778
  _COLLECTOROUTPUT._serialized_end=5117
  _COUNTCOLLECTOR._serialized_start=5119
  _COUNTCOLLECTOR._serialized_end=5135
  _COUNTCOLLECTOROUTPUT._serialized_start=5137
  _COUNTCOLLECTOROUTPUT._serialized_end=5174
  _FACETCOLLECTOR._serialized_start=5176
  _FACETCOLLECTOR._serialized_end=5223
  _FACETCOLLECTOROUTPUT._serialized_start=5226
  _FACETCOLLECTOROUTPUT._serialized_end=5374
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._serialized_start=5324
  _FACETCOLLECTOROUTPUT_FACETCOUNTSENTRY._serialized_end=5374
  _RESERVOIRSAMPLINGCOLLECTOR._serialized_start=5376
  _RESERVOIRSAMPLINGCOLLECTOR._serialized_end=5435
  _RANDOMDOCUMENT._serialized_start=5437
  _RANDOMDOCUMENT._serialized_end=5527
  _RESERVOIRSAMPLINGCOLLECTOROUTPUT._serialized_start=5529
  _RESERVOIRSAMPLINGCOLLECTOROUTPUT._serialized_end=5618
  _TOPDOCSCOLLECTOR._serialized_start=5621
  _TOPDOCSCOLLECTOR._serialized_end=5868
  _TOPDOCSCOLLECTOR_SNIPPETSENTRY._serialized_start=5810
  _TOPDOCSCOLLECTOR_SNIPPETSENTRY._serialized_end=5857
  _TOPDOCSCOLLECTOROUTPUT._serialized_start=5870
  _TOPDOCSCOLLECTOROUTPUT._serialized_end=5967
  _AGGREGATIONCOLLECTOR._serialized_start=5970
  _AGGREGATIONCOLLECTOR._serialized_end=6146
  _AGGREGATIONCOLLECTOR_AGGREGATIONSENTRY._serialized_start=6069
  _AGGREGATIONCOLLECTOR_AGGREGATIONSENTRY._serialized_end=6146
  _AGGREGATIONCOLLECTOROUTPUT._serialized_start=6149
  _AGGREGATIONCOLLECTOROUTPUT._serialized_end=6362
  _AGGREGATIONCOLLECTOROUTPUT_AGGREGATIONRESULTSENTRY._serialized_start=6273
  _AGGREGATIONCOLLECTOROUTPUT_AGGREGATIONRESULTSENTRY._serialized_end=6362
  _AGGREGATIONRESULT._serialized_start=6365
  _AGGREGATIONRESULT._serialized_end=6496
  _BUCKETRESULT._serialized_start=6499
  _BUCKETRESULT._serialized_end=6667
  _RANGERESULT._serialized_start=6669
  _RANGERESULT._serialized_end=6730
  _HISTOGRAMRESULT._serialized_start=6732
  _HISTOGRAMRESULT._serialized_end=6792
  _TERMSRESULT._serialized_start=6795
  _TERMSRESULT._serialized_end=6954
  _METRICRESULT._serialized_start=6957
  _METRICRESULT._serialized_end=7089
  _SINGLEMETRICRESULT._serialized_start=7091
  _SINGLEMETRICRESULT._serialized_end=7141
  _STATSRESULT._serialized_start=7144
  _STATSRESULT._serialized_end=7319
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: beacon_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x62\x65\x61\x63on_service.proto\x12\x0bsumma.proto\"L\n\x13PublishIndexRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12\x14\n\x07payload\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_payload\"$\n\x14PublishIndexResponse\x12\x0c\n\x04hash\x18\x01 \x01(\t2c\n\tBeaconApi\x12V\n\rpublish_index\x12 .summa.proto.PublishIndexRequest\x1a!.summa.proto.PublishIndexResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'beacon_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBLISHINDEXREQUEST._serialized_start=37
  _PUBLISHINDEXREQUEST._serialized_end=113
  _PUBLISHINDEXRESPONSE._serialized_start=115
  _PUBLISHINDEXRESPONSE._serialized_end=151
  _BEACONAPI._serialized_start=153
  _BEACONAPI._serialized_end=252
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import consumer_service_pb2 as consumer__service__pb2


class ConsumerApiStub(object):
    """Manages consumers that ingest data from Kafka
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_consumer = channel.unary_unary(
                '/summa.proto.ConsumerApi/create_consumer',
                request_serializer=consumer__service__pb2.CreateConsumerRequest.SerializeToString,
                response_deserializer=consumer__service__pb2.CreateConsumerResponse.FromString,
                )
        self.get_consumer = channel.unary_unary(
                '/summa.proto.ConsumerApi/get_consumer',
                request_serializer=consumer__service__pb2.GetConsumerRequest.SerializeToString,
                response_deserializer=consumer__service__pb2.GetConsumerResponse.FromString,
                )
        self.get_consumers = channel.unary_unary(
                '/summa.proto.ConsumerApi/get_consumers',
                request_serializer=consumer__service__pb2.GetConsumersRequest.SerializeToString,
                response_deserializer=consumer__service__pb2.GetConsumersResponse.FromString,
                )
        self.delete_consumer = channel.unary_unary(
                '/summa.proto.ConsumerApi/delete_consumer',
                request_serializer=consumer__service__pb2.DeleteConsumerRequest.SerializeToString,
                response_deserializer=consumer__service__pb2.DeleteConsumerResponse.FromString,
                )


class ConsumerApiServicer(object):
    """Manages consumers that ingest data from Kafka
    """

    def create_consumer(self, request, context):
        """Create a new consumer
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_consumer(self, request, context):
        """Get a single consumer
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_consumers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_consumer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ConsumerApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_consumer': grpc.unary_unary_rpc_method_handler(
                    servicer.create_consumer,
                    request_deserializer=consumer__service__pb2.CreateConsumerRequest.FromString,
                    response_serializer=consumer__service__pb2.CreateConsumerResponse.SerializeToString,
            ),
            'get_consumer': grpc.unary_unary_rpc_method_handler(
                    servicer.get_consumer,
                    request_deserializer=consumer__service__pb2.GetConsumerRequest.FromString,
                    response_serializer=consumer__service__pb2.GetConsumerResponse.SerializeToString,
            ),
            'get_consumers': grpc.unary_unary_rpc_method_handler(
                    servicer.get_consumers,
                    request_deserializer=consumer__service__pb2.GetConsumersRequest.FromString,
                    response_serializer=consumer__service__pb2.GetConsumersResponse.SerializeToString,
            ),
            'delete_consumer': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_consumer,
                    request_deserializer=consumer__service__pb2.DeleteConsumerRequest.FromString,
                    response_serializer=consumer__service__pb2.DeleteConsumerResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'summa.proto.ConsumerApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ConsumerApi(object):
    """Manages consumers that ingest data from Kafka
    """

    @staticmethod
    def create_consumer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.ConsumerApi/create_consumer',
            consumer__service__pb2.CreateConsumerRequest.SerializeToString,
            consumer__service__pb2.CreateConsumerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_consumer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.ConsumerApi/get_consumer',
            consumer__service__pb2.GetConsumerRequest.SerializeToString,
            consumer__service__pb2.GetConsumerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_consumers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.ConsumerApi/get_consumers',
            consumer__service__pb2.GetConsumersRequest.SerializeToString,
            consumer__service__pb2.GetConsumersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_consumer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/summa.proto.ConsumerApi/delete_consumer',
            consumer__service__pb2.DeleteConsumerRequest.SerializeToString,
            consumer__service__pb2.DeleteConsumerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import query_pb2 as query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14search_service.proto\x12\x0bsumma.proto\x1a\x0bquery.proto\"\xd4\x01\n\rSearchRequest\x12\x13\n\x0bindex_alias\x18\x01 \x01(\t\x12!\n\x05query\x18\x02 \x01(\x0b\x32\x12.summa.proto.Query\x12*\n\ncollectors\x18\x03 \x03(\x0b\x32\x16.summa.proto.Collector\x12\x32\n\x04tags\x18\x04 \x03(\x0b\x32$.summa.proto.SearchRequest.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32P\n\tSearchApi\x12\x43\n\x06search\x12\x1a.summa.proto.SearchRequest\x1a\x1b.summa.proto.SearchResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'search_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SEARCHREQUEST_TAGSENTRY._options = None
  _SEARCHREQUEST_TAGSENTRY._serialized_options = b'8\001'
  _SEARCHREQUEST._serialized_start=51
  _SEARCHREQUEST._serialized_end=263
  _SEARCHREQUEST_TAGSENTRY._serialized_start=220
  _SEARCHREQUEST_TAGSENTRY._serialized_end=263
  _SEARCHAPI._serialized_start=265
  _SEARCHAPI._serialized_end=345
# @@protoc_insertion_point(module_scope)
